@@ -16,8 +16,6 @@ using namespace QAccessibleClient;
 DBusConnection::DBusConnection()
     : QObject()
     , m_connection(QDBusConnection::sessionBus())
-    , m_status(Disconnected)
-    , m_initWatcher(nullptr)
 {
     init();
 }
