@@ -7,7 +7,6 @@
 #ifndef DBUSCONNECTION_H
 #define DBUSCONNECTION_H
 
-#include <QString>
 #include <QObject>
 #include <QDBusConnection>
 #include <QDBusPendingCallWatcher>
@@ -95,8 +94,8 @@ private:
     void init();
 
     QDBusConnection m_connection;
-    mutable Status m_status;
-    QDBusPendingCallWatcher *m_initWatcher;
+    mutable Status m_status = Disconnected;
+    QDBusPendingCallWatcher *m_initWatcher = nullptr;
 };
 }
 
